==> crypto-2.6.1.tgz: package/Ion/Ion.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Ion = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M7.026 19.009c1.352 3.793 4.962 6.508 9.202 6.508a9.76 9.76 0 002.161-.241A2.707 2.707 0 0020.91 27a2.712 2.712 0 002.705-2.718c0-.598-.192-1.15-.518-1.6A9.811 9.811 0 0026 15.699a9.809 9.809 0 00-2.616-6.686 2.71 2.71 0 00.326-1.294A2.712 2.712 0 0021.005 5a2.7 2.7 0 00-2.252 1.21 9.742 9.742 0 00-2.525-.33c-4.677 0-8.586 3.301-9.546 7.711A2.712 2.712 0 004 16.31a2.712 2.712 0 003.026 2.7zm.49-.105a2.718 2.718 0 001.895-2.595c0-1.338-.963-2.45-2.23-2.676.935-4.154 4.63-7.255 9.047-7.255.788 0 1.553.098 2.283.284a2.72 2.72 0 00-.212 1.056 2.712 2.712 0 002.706 2.719c.845 0 1.6-.39 2.095-1a9.311 9.311 0 012.405 6.261 9.314 9.314 0 01-2.736 6.61 2.69 2.69 0 00-1.86-.745 2.712 2.712 0 00-2.658 3.234 9.267 9.267 0 01-2.023.222c-4.002 0-7.412-2.547-8.713-6.115zM16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm.228-13.58a2.715 2.715 0 002.709-2.722c0-1.503-1.213-2.721-2.709-2.721s-2.708 1.218-2.708 2.721a2.715 2.715 0 002.708 2.722z"
  }));
});
Ion.displayName = 'Ion';
export const IonDimensions = {
  height: 32,
  width: 32
};

==> crypto-2.7.1.tgz: package/Ion/Ion.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Ion = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M7.026 19.009c1.352 3.793 4.962 6.508 9.202 6.508a9.76 9.76 0 002.161-.241A2.707 2.707 0 0020.91 27a2.712 2.712 0 002.705-2.718c0-.598-.192-1.15-.518-1.6A9.811 9.811 0 0026 15.699a9.809 9.809 0 00-2.616-6.686 2.71 2.71 0 00.326-1.294A2.712 2.712 0 0021.005 5a2.7 2.7 0 00-2.252 1.21 9.742 9.742 0 00-2.525-.33c-4.677 0-8.586 3.301-9.546 7.711A2.712 2.712 0 004 16.31a2.712 2.712 0 003.026 2.7zm.49-.105a2.718 2.718 0 001.895-2.595c0-1.338-.963-2.45-2.23-2.676.935-4.154 4.63-7.255 9.047-7.255.788 0 1.553.098 2.283.284a2.72 2.72 0 00-.212 1.056 2.712 2.712 0 002.706 2.719c.845 0 1.6-.39 2.095-1a9.311 9.311 0 012.405 6.261 9.314 9.314 0 01-2.736 6.61 2.69 2.69 0 00-1.86-.745 2.712 2.712 0 00-2.658 3.234 9.267 9.267 0 01-2.023.222c-4.002 0-7.412-2.547-8.713-6.115zM16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zm.228-13.58a2.715 2.715 0 002.709-2.722c0-1.503-1.213-2.721-2.709-2.721s-2.708 1.218-2.708 2.721a2.715 2.715 0 002.708 2.722z"
  }));
});
Ion.displayName = 'Ion';
export var IonDimensions = {
  height: 32,
  width: 32
};
